@@ -1,8 +1,9 @@
 from optimade.server.mappers.entries import BaseResourceMapper
+from optimade.models.references import ReferenceResource
 
 __all__ = ("ReferenceMapper",)
 
 
 class ReferenceMapper(BaseResourceMapper):
 
-    ENDPOINT = "references"
+    ENTRY_RESOURCE_CLASS = ReferenceResource
